// SPDX-License-Identifier: BUSL-1.1
pragma solidity 0.8.21;

import "@openzeppelin/contracts/token/ERC20/utils/SafeERC20.sol";
import "../abstract/roles/EeseeRoleHandler.sol";

contract EeseeAirdrop is EeseeRoleHandler {
    using SafeERC20 for IERC20;

    struct Recipient {
        address recipient;
        uint256 amount;
    }

    ///@dev Airdrop role af defined in {accessManager}.
    bytes32 private constant AIRDROP_ROLE = keccak256("AIRDROP_ROLE");

    error InvalidESE();

    constructor(IEeseeAccessManager _accessManager) EeseeRoleHandler(_accessManager) {
    }

    /**
     * @dev Airdrops tokens to recipients.
     * @param token - Token to airdrop.
     * @param recipients - Recipients' addresses and amounts they receive.
     * Note: This function can only be called by AIRDROP_ROLE.
     */
    function airdrop(IERC20 token, Recipient[] calldata recipients) external onlyRole(AIRDROP_ROLE) {
        for(uint256 i; i < recipients.length;) {
            token.safeTransfer(recipients[i].recipient, recipients[i].amount);
            unchecked { ++i; }
        }
    }
}
